@@ -154,20 +154,25 @@ class BaseDocumentViewSet(ReadOnlyModelViewSet):
     ignore = []
 
     def __init__(self, *args, **kwargs):
-        assert self.document is not None
+        self.run_checks()
+
+        if self.document:
+            self.client = connections.get_connection(
+                self.document._get_using()
+            )
+            self.index = self.document._index._name
+            self.mapping = self.document._doc_type.mapping.properties.name
+            self.search = Search(
+                using=self.client,
+                index=self.index,
+                doc_type=self.document._doc_type.name
+            )
 
-        self.client = connections.get_connection(
-            self.document._get_using()
-        )
-        self.index = self.document._index._name
-        self.mapping = self.document._doc_type.mapping.properties.name
-        self.search = Search(
-            using=self.client,
-            index=self.index,
-            doc_type=self.document._doc_type.name
-        )
         super(BaseDocumentViewSet, self).__init__(*args, **kwargs)
 
+    def run_checks(self):
+        assert self.document is not None
+
     def get_queryset(self):
         """Get queryset."""
         queryset = self.search.query()
